==========================
 :mod:`zope.password` API
==========================

Interfaces
==========

.. automodule:: zope.password.interfaces
   :members:
   :member-order: bysource


Password Manager Implementations
================================

.. automodule:: zope.password.password
   :members:
   :member-order: bysource


Deprecated Implementations
--------------------------

.. warning::

   The following password managers are deprecated, because they produce
   unacceptably-weak password hashes.  They are only included to allow
   apps which previously used them to migrate smoothly to a supported
   implementation.

.. automodule:: zope.password.legacy
   :members:
   :member-order: bysource


Vocabulary
==========

.. automodule:: zope.password.vocabulary
   :members:
   :member-order: bysource
